@@ -74,11 +74,13 @@ class ZeroShotClassifierAnnotator(AnnotatorBase):
         # Create cached pipeline context with model
         p: ZeroShotClassificationPipeline = get_pipeline(params.model)
         candidate_labels = comma_separated_to_list(params.candidate_labels)
-        for document in documents:
-            if params.processing_unit == ProcessingUnit.document:
-                result = p(document.text, params.candidate_labels, hypothesis_template=params.hypothesis_template)
-                document.categories = compute_categories(result, params.multi_label_threshold, params.multi_label)
-            elif params.processing_unit == ProcessingUnit.segment:
+        if params.processing_unit == ProcessingUnit.document:
+            dtexts = [document.text for document in documents]
+            results = p(dtexts, candidate_labels, hypothesis_template=params.hypothesis_template)
+            for doc, result in zip(documents, results):
+                doc.categories = compute_categories(result, params.multi_label_threshold, params.multi_label)
+        else:
+            for document in documents:
                 if not document.sentences:
                     document.sentences = [Sentence(start=0, end=len(document.text))]
                 stexts = [document.text[s.start:s.end] for s in document.sentences]
